﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace DanceCompetition
{

    public partial class JudgePDA : System.Web.UI.Page
    {
        /// <summary>
        /// This method redirect the page and add the url argument string
        /// Also, it disable the checking couple ID button as soon as the recalled threshold is reach.
        /// </summary>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (Request.QueryString.Count == 0)
            {
                Response.Redirect("JudgePDA.aspx?queueNo=1");
            }
            else
            {
                //First we check if the page is loaded for the first time, 
                if (!IsPostBack)
                {
                    ViewState["PostBackCounter"] = 0;
                }
                //Now, we assign the variable value in the text box
                int counter = (int)ViewState["PostBackCounter"];
                LimitLabel.Text = "Recalled :<b>" + counter.ToString() + " couple(s).</b><br/>";

                CoupleListView.Enabled = true;
                MissingCoupleListView.Enabled = true;

                if (String.Compare(Request.QueryString["QueueNo"].ToString(),"1")==0)
                {
                    BtnPrev.Enabled = false;
                }
            }
        }

        /// <summary>
        /// This methods manage the checking couple Id buttons
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void CoupleListView_ItemCommand(object sender, ListViewCommandEventArgs e)
        {
            switch (e.CommandName)
            {
                case "UpdateRecall":
                    String coupleID = e.CommandArgument.ToString();
                    String judgeID = JudgeDropDownList.SelectedValue.ToString();
                    String eventID = EventInfoGridView.Rows[0].Cells[0].Text;


                    // Create the recallTableAdapter
                    DanceCompetition.CompetitionTableAdapters.RecallTableAdapter recallTableAdapter =
                        new DanceCompetition.CompetitionTableAdapters.RecallTableAdapter();
                    // Update the Recall couple
                    recallTableAdapter.UpdateRecallCouple(judgeID, eventID, coupleID);

                    String limit = EventInfoGridView.Rows[0].Cells[5].Text;

                    //Count the click
                    int oldCount = (int)ViewState["PostBackCounter"];
                    int newCount = oldCount + 1;
                    if (String.Compare(newCount.ToString(), limit) == 0)
                    {
                        
                        CoupleListView.Enabled = false;
                        MissingCoupleListView.Enabled = false;
                        LimitLabel.Text = "<b>Recall Couples Completed. Choose next dance OR event.</b><br/>";
                    }
                    else
                    {
                        LimitLabel.Text = "Recalled:<b>" + newCount.ToString() + " couple(s). </b><br/>";
                    }
                    
                    //Secondly, we replace the old value of the view state so that the new value is read the next //time
                    ViewState["PostBackCounter"] = newCount;

                    CoupleListView.DataBind();
                    RecalledCoupleListView.DataBind();




                    break;
            }
        }
        /// <summary>
        /// This method handlge the missing couple ID buttons
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void MissingCoupleListView_ItemCommand(object sender, ListViewCommandEventArgs e)
        {
            switch (e.CommandName)
            {
                case "UpdateRecall":
                    String coupleID = e.CommandArgument.ToString();
                    String judgeID = JudgeDropDownList.SelectedValue.ToString();
                    String eventID = EventInfoGridView.Rows[0].Cells[0].Text;


                    // Create the recallTableAdapter
                    DanceCompetition.CompetitionTableAdapters.RecallTableAdapter missingRecallTableAdapter =
                        new DanceCompetition.CompetitionTableAdapters.RecallTableAdapter();
                    // Update the Recall couple
                    missingRecallTableAdapter.UpdateRecallCouple(judgeID, eventID, coupleID);

                    String limit = EventInfoGridView.Rows[0].Cells[5].Text;

                    //Count the click
                    int oldCount = (int)ViewState["PostBackCounter"];
                    int newCount = oldCount + 1;
                    if (String.Compare(newCount.ToString(), limit) == 0)
                    {
                        
                        CoupleListView.Enabled = false;
                        MissingCoupleListView.Enabled = false;
                        LimitLabel.Text = "<b>Recall Couples Completed. Choose next dance OR event.</b><br/>";
                    }
                    else
                    {
                        LimitLabel.Text = "Recalled:<b>" + newCount.ToString() + " couple(s). </b><br/>";
                    }
                    
                    //Secondly, we replace the old value of the view state so that the new value is read the next //time
                    ViewState["PostBackCounter"] = newCount;

                    
                    RecalledCoupleListView.DataBind();                    
                    MissingCoupleListView.DataBind();


                    break;
            }






        }
        /// <summary>
        /// This methods manages the recall couple ID buttons
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void RecalledCoupleListView_ItemCommand(object sender, ListViewCommandEventArgs e)
        {
            switch (e.CommandName)
            {
                case "UnRecall":
                    String coupleID = e.CommandArgument.ToString();
                    String judgeID = JudgeDropDownList.SelectedValue.ToString();
                    String eventID = EventInfoGridView.Rows[0].Cells[0].Text;


                    // Create the recallTableAdapter
                    DanceCompetition.CompetitionTableAdapters.RecallTableAdapter recalledCoupleTableAdapter =
                        new DanceCompetition.CompetitionTableAdapters.RecallTableAdapter();
                    // Update the Recall couple
                    recalledCoupleTableAdapter.UnRecallCouple(judgeID, eventID, coupleID);

                    String limit = EventInfoGridView.Rows[0].Cells[5].Text;

                    //Count the click
                    int oldCount = (int)ViewState["PostBackCounter"];
                    int newCount = oldCount - 1;
                    if (String.Compare(newCount.ToString(), limit) == 0)
                    {
                        
                        CoupleListView.Enabled = false;
                        MissingCoupleListView.Enabled = false;
                        LimitLabel.Text = "<b>Recall Couples Completed. Choose next dance OR event.</b><br/>";
                    }
                    else
                    {
                        LimitLabel.Text = "Recalled:<b>" + newCount.ToString() + " couple(s). </b><br/>";
                        CoupleListView.Enabled = true;
                        MissingCoupleListView.Enabled = true;
                    }
                    
                    //Secondly, we replace the old value of the view state so that the new value is read the next //time
                    ViewState["PostBackCounter"] = newCount;

                    RecalledCoupleListView.DataBind();
                    CoupleListView.DataBind();
                    MissingCoupleListView.DataBind();




                    break;
                    }
        }
        /// <summary>
        /// This method handles the dance drop down list
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void DanceDropDownList_SelectedIndexChanged(object sender, EventArgs e)
        {
            ViewState["PostBackCounter"] = 0;
            //Now, we assign the variable value in the text box
            int counter = (int)ViewState["PostBackCounter"];
            LimitLabel.Text = "Recalled :<b>" + counter.ToString() + " couple(s).</b><br/>";
        }

        /// <summary>
        /// this method handles the judge drop down list
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void JudgeDropDownList_SelectedIndexChanged(object sender, EventArgs e)
        {
            ViewState["PostBackCounter"] = 0;
            //Now, we assign the variable value in the text box
            int counter = (int)ViewState["PostBackCounter"];
            LimitLabel.Text = "Recalled :<b>" + counter.ToString() + " couple(s).</b><br/>";

           
            DanceDropDownList.DataBind();
        }

        /// <summary>
        /// This method handles Next Click button
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void BtnNext_Click(object sender, EventArgs e)
        {
            int queueNo = Convert.ToInt16(Request.QueryString[0]);
            queueNo = queueNo + 1;
            Response.Redirect("JudgePDA.aspx?QueueNo=" + queueNo.ToString());
        }
        /// <summary>
        /// This method handles Prev Click button
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void BtnPrev_Click(object sender, EventArgs e)
        {
            int queueNo = Convert.ToInt16(Request.QueryString[0]);
            queueNo = queueNo - 1;
            Response.Redirect("JudgePDA.aspx?QueueNo=" + queueNo.ToString());
        }
    }
}
